@@ -3,5 +3,5 @@
 """
 __init__
 """
-from matching import (nlp,numeric_matching,text_matching)
+import (nlp,numeric_matching,text_matching)
 __all__ = [nlp,numeric_matching,text_matching]
\ No newline at end of file
